@@ -1,6 +1,6 @@
 from .find_common import find_common
 from .MaskSet import MaskSet, Mask
-from .Navigator import Navigator
+#from .Navigator import Navigator
 from .wikipedia import Wikipedia
 from .Scraper import Scraper
 from .get_id_token import get_id_token
